iptraf-ng 1.1.2

Signed-off-by: Nikola Pajkovsky <npajkovs@redhat.com>
This commit is contained in:
Nikola Pajkovsky 2012-05-04 10:22:38 +02:00
parent eaf8e812c4
commit 731497bf86
4 changed files with 6 additions and 46 deletions

1
.gitignore vendored
View File

@ -1,3 +1,4 @@
/iptraf-ng-1.1.0.tar.gz
/iptraf-ng-1.1.1.tar.gz
/iptraf-ng-1.1.2.rc0.tar.gz
/iptraf-ng-1.1.2.tar.gz

View File

@ -1,44 +0,0 @@
From b78e62ca2bf6dc887963071d02c7c21ba7355989 Mon Sep 17 00:00:00 2001
Message-Id: <b78e62ca2bf6dc887963071d02c7c21ba7355989.1326710977.git.npajkovs@redhat.com>
From: Nikola Pajkovsky <npajkovs@redhat.com>
Date: Mon, 16 Jan 2012 11:47:01 +0100
Subject: [PATCH] fix wrongly used execl
Signed-off-by: Nikola Pajkovsky <npajkovs@redhat.com>
---
src/itrafmon.c | 19 +++++++++++--------
1 files changed, 11 insertions(+), 8 deletions(-)
diff --git a/src/itrafmon.c b/src/itrafmon.c
index 2669a54..040b0e0 100644
--- a/src/itrafmon.c
+++ b/src/itrafmon.c
@@ -502,14 +502,17 @@ int checkrvnamed(void)
indicate("Starting reverse lookup server");
if ((cpid = fork()) == 0) {
- execl("rvnamed-ng", "", (char*)NULL);
-
- /*
- * execl() never returns, so if we reach this point, we have
- * a problem.
- */
-
- die("unable execl() rvnamed-ng");
+ char *args[] = {
+ "rvnamed-ng",
+ NULL
+ };
+ execvp("rvnamed-ng", args);
+ /*
+ * execvp() never returns, so if we reach this point, we have
+ * a problem.
+ */
+
+ die("unable execvp() rvnamed-ng");
} else if (cpid == -1) {
write_error("Can't spawn new process; lookups will block",
daemonized);
--
1.7.8

View File

@ -1,6 +1,6 @@
Summary: A console-based network monitoring utility
Name: iptraf-ng
Version: 1.1.2.rc0
Version: 1.1.2
Release: 1%{?dist}
Source0: https://fedorahosted.org/releases/i/p/iptraf-ng/%{name}-%{version}.tar.gz
Source1: iptraf-ng-logrotate.conf
@ -66,6 +66,9 @@ rm -rf $RPM_BUILD_ROOT
%config(noreplace) %{_sysconfdir}/logrotate.d/iptraf-ng
%changelog
* Fri May 04 2012 Nikola Pajkovsky <npajkovs@redhat.com> - 1.1.2-1
- new upstream iptraf-ng-1.1.2-1
* Fri Apr 27 2012 Nikola Pajkovsky <npajkovs@redhat.com> - 1.1.2.rc0-1
- new upstream iptraf-ng-1.1.2.rc0-1

View File

@ -1 +1 @@
042fe41c19931d2d8fe1b296c855d2dd iptraf-ng-1.1.2.rc0.tar.gz
60a9a2f5bd658befac642d4b582e287c iptraf-ng-1.1.2.tar.gz